<?php

namespace Lavalite\Marketplace\Policies;

use Litepie\User\Contracts\UserPolicy;
use Lavalite\Marketplace\Models\Marketplace;

class MarketplacePolicy
{

    /**
     * Determine if the given user can view the marketplace.
     *
     * @param UserPolicy $user
     * @param Marketplace $marketplace
     *
     * @return bool
     */
    public function view(UserPolicy $user, Marketplace $marketplace)
    {
        if ($user->canDo('marketplace.marketplace.view') && $user->isAdmin()) {
            return true;
        }

        return $marketplace->user_id == user_id() && $marketplace->user_type == user_type();
    }

    /**
     * Determine if the given user can create a marketplace.
     *
     * @param UserPolicy $user
     * @param Marketplace $marketplace
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('marketplace.marketplace.create');
    }

    /**
     * Determine if the given user can update the given marketplace.
     *
     * @param UserPolicy $user
     * @param Marketplace $marketplace
     *
     * @return bool
     */
    public function update(UserPolicy $user, Marketplace $marketplace)
    {
        if ($user->canDo('marketplace.marketplace.edit') && $user->isAdmin()) {
            return true;
        }

        return $marketplace->user_id == user_id() && $marketplace->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given marketplace.
     *
     * @param UserPolicy $user
     * @param Marketplace $marketplace
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Marketplace $marketplace)
    {
        return $marketplace->user_id == user_id() && $marketplace->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given marketplace.
     *
     * @param UserPolicy $user
     * @param Marketplace $marketplace
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Marketplace $marketplace)
    {
        if ($user->canDo('marketplace.marketplace.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given marketplace.
     *
     * @param UserPolicy $user
     * @param Marketplace $marketplace
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Marketplace $marketplace)
    {
        if ($user->canDo('marketplace.marketplace.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
