<?php

namespace Lavalite\Marketplace\Providers;

use Illuminate\Support\ServiceProvider;

class MarketplaceServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'marketplace');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'marketplace');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('lavalite.marketplace', function ($app) {
            return $this->app->make('Lavalite\Marketplace\Marketplace');
        });

        // Bind Marketplace to repository
        $this->app->bind(
            'Lavalite\Marketplace\Interfaces\MarketplaceRepositoryInterface',
            \Lavalite\Marketplace\Repositories\Eloquent\MarketplaceRepository::class
        );
        // Bind Category to repository
        $this->app->bind(
            'Lavalite\Marketplace\Interfaces\CategoryRepositoryInterface',
            \Lavalite\Marketplace\Repositories\Eloquent\CategoryRepository::class
        );
        // Bind Review to repository
        $this->app->bind(
            'Lavalite\Marketplace\Interfaces\ReviewRepositoryInterface',
            \Lavalite\Marketplace\Repositories\Eloquent\ReviewRepository::class
        );

        $this->app->register(\Lavalite\Marketplace\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Lavalite\Marketplace\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['lavalite.marketplace'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('lavalite/marketplace.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/marketplace')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/marketplace')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
